@@ -9,12 +9,21 @@
 #' @param Xdyad an n x n x pd array of dyadic covariates
 #' @param intercept logical
 #' @param n number of rows/columns
-#' @return an n x n x (pr+pc+pd+intercept) 3-way array
+#' @return an n x n x (pr+pc+pd+intercept) 3-way array 
 #' @author Peter Hoff
 #' @export design_array
-design_array<-function(Xrow=NULL,Xcol=NULL,Xdyad=NULL,intercept=TRUE,n)
+design_array<-function(Xrow=NULL,Xcol=NULL,Xdyad=NULL,intercept=TRUE,n=NULL)
 { 
 
+if(is.null(n))
+{
+  if(is.matrix(Xrow)){ n<-nrow(Xrow) }
+  if(is.matrix(Xcol)){ n<-nrow(Xcol) }
+  if(is.matrix(Xdyad)){ n<-nrow(Xdyad) }
+  if(is.array(Xdyad)){ n<-dim(Xdyad)[1] }  
+  if(is.null(n)){ cat("Error: n must be specified") }
+}
+
 
 ### covariate array
 pr<-length(Xrow)/n
@@ -25,6 +34,7 @@ dnX<-NULL
 ###
 
 
+
 ### row covariates
 if(pr>0)
 {
@@ -58,9 +68,12 @@ if(pd>0)
 }      
 ###
 
+# ### remove constant predictors
+# if(rmcc){ X<-X[,,apply(X,3,sd,na.rm=TRUE)>0,drop=FALSE] }
+
 
 ### add intercept 
-if(!any(apply(X,3,function(x){var(c(x),na.rm=TRUE)})==0) & intercept )
+if(!any(apply(X,3,function(x){var(c(x),na.rm=TRUE)})==0) & intercept)
 {
   X1<-array(dim=c(0,0,1)+dim(X))
   X1[,,1]<-1 ; X1[,,-1]<-X
@@ -84,6 +97,9 @@ if( sum(is.na(X)) > sum( is.na(apply(X,3,diag)) ) )
 X[is.na(X)]<-0
 ###
 
+### do precomputations
+X<-precomputeX(X)
+###
 
 X
 }
