@@ -12,10 +12,11 @@
 #' @export simZ
 simZ <-
 function(EZ,rho,s2=1)
-{
-  w1<-sqrt((1 + sqrt(1-rho^2))/2)
-  w2<-sign(rho)*sqrt(1-w1^2)
+{ 
+  c<-(sqrt(1+rho) + sqrt(1-rho))/2
+  d<-(sqrt(1+rho) - sqrt(1-rho))/2
   EC<-matrix(rnorm(length(EZ)),nrow(EZ),nrow(EZ))
-  EC<- sqrt(s2)*( w1*EC + w2*t(EC) )
+  EC<- sqrt(s2)*( c*EC + d*t(EC) )
   EZ+EC    
-}
+} 
+
