@@ -7,12 +7,11 @@
 #' @return a summary of parameter estimates and confidence intervals for an AME
 #' fit
 #' @author Peter Hoff
-#' @S3method summary ame 
+#' @exportS3Method amen::summary
 summary.ame <-
 function(object, ...)
 { 
   fit<-object
-  require(amen)
   tmp<-cbind(apply(fit$BETA,2,mean), apply(fit$BETA,2,sd) ,
        apply(fit$BETA,2,mean)/apply(fit$BETA,2,sd) , 
        2*(1-pnorm( abs(apply(fit$BETA,2,mean)/apply(fit$BETA,2,sd)))))
